Documentation
¶
Index ¶
- type URL
- func (u *URL) Args(args map[string]string) *URL
- func (u *URL) ConsumeAPI(dest interface{}) error
- func (u *URL) Domain(d string) *URL
- func (u *URL) Full() (string, string, io.Reader)
- func (u *URL) Method(m string) *URL
- func (u *URL) Pagination(page interface{}, per interface{}) *URL
- func (u *URL) Path(pp ...string) *URL
- func (u *URL) Payload(pl map[string]string) *URL
- func (u *URL) Secure() *URL
- func (u *URL) SetPaginationArgNames(pageNo string, numberPerPage string) *URL
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type URL ¶
type URL struct {
ArgMap map[string]string
HeadersMap map[string]string
PayloadMap map[string]string
// contains filtered or unexported fields
}
func DefaultURL ¶
func DefaultURL() *URL
func (*URL) ConsumeAPI ¶
ConsumeAPI is the default method for firing the HTTP request
func (*URL) Pagination ¶
Pagination sets the pagination variables
func (*URL) Path ¶
Path accepts a number of strings and adjoins them by "/" in the order they are given and uses them as the path of a the request URL
Click to show internal directories.
Click to hide internal directories.